# Changelog

## 0.9.0 (2025-08-22)

Full Changelog: [v0.8.0...v0.9.0](https://github.com/Fluidize-Inc/fluidize-python-sdk/compare/v0.8.0...v0.9.0)

### Features

* **api:** api update ([34f3b9e](https://github.com/Fluidize-Inc/fluidize-python-sdk/commit/34f3b9e0491fa37afe83da36d7fe02166379982c))
* **api:** manual updates ([eb1b795](https://github.com/Fluidize-Inc/fluidize-python-sdk/commit/eb1b79598849320b281fa3b9e122cfb3a9d1b1df))

## 0.8.0 (2025-08-22)

Full Changelog: [v0.7.1...v0.8.0](https://github.com/Fluidize-Inc/fluidize-python-sdk/compare/v0.7.1...v0.8.0)

### Features

* **api:** manual updates ([ab2cdb9](https://github.com/Fluidize-Inc/fluidize-python-sdk/commit/ab2cdb9c0f128ff1b0135d5998df50115b8af623))

## 0.7.1 (2025-08-22)

Full Changelog: [v0.7.0...v0.7.1](https://github.com/Fluidize-Inc/fluidize-python-sdk/compare/v0.7.0...v0.7.1)

### Chores

* update github action ([3ef7ab3](https://github.com/Fluidize-Inc/fluidize-python-sdk/commit/3ef7ab37b52f07e2a7762234861b7d20a8050666))

## 0.7.0 (2025-08-18)

Full Changelog: [v0.6.0...v0.7.0](https://github.com/Fluidize-Inc/fluidize-python-sdk/compare/v0.6.0...v0.7.0)

### Features

* **api:** api update ([f9c6bf4](https://github.com/Fluidize-Inc/fluidize-python-sdk/commit/f9c6bf4aee805b48bb287f20913563cb98edee38))
* **api:** api update ([24506d1](https://github.com/Fluidize-Inc/fluidize-python-sdk/commit/24506d13f3c43356a7a04587791ca630e1ace250))
* **api:** manual updates ([71befc1](https://github.com/Fluidize-Inc/fluidize-python-sdk/commit/71befc199f7bcc7a10709954208d621d0bf25cee))

## 0.6.0 (2025-08-16)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/Fluidize-Inc/fluidize-python-sdk/compare/v0.5.0...v0.6.0)

### Features

* **api:** simulation list updated ([0e0901d](https://github.com/Fluidize-Inc/fluidize-python-sdk/commit/0e0901d90e81c12f40fdab75555c90c8cab1365d))

## 0.5.0 (2025-08-16)

Full Changelog: [v0.4.1...v0.5.0](https://github.com/Fluidize-Inc/fluidize-python-sdk/compare/v0.4.1...v0.5.0)

### Features

* **api:** api update ([d33c6fd](https://github.com/Fluidize-Inc/fluidize-python-sdk/commit/d33c6fd30e636e573e1fcc3a25ad0827b305d771))

## 0.4.1 (2025-08-14)

Full Changelog: [v0.4.0...v0.4.1](https://github.com/Fluidize-Inc/fluidize-python-sdk/compare/v0.4.0...v0.4.1)

### Chores

* **internal:** codegen related update ([0be2e98](https://github.com/Fluidize-Inc/fluidize-python-sdk/commit/0be2e98c8c40026060a29299c4bc05ed0ab74ed1))

## 0.4.0 (2025-08-10)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/Fluidize-Inc/fluidize-python-sdk/compare/v0.3.0...v0.4.0)

### Features

* **api:** new version pushing, contact email provided ([276cbcc](https://github.com/Fluidize-Inc/fluidize-python-sdk/commit/276cbcc68eeddce97af1f824daf3f0a8f8ed5c44))


### Chores

* update SDK settings ([94df184](https://github.com/Fluidize-Inc/fluidize-python-sdk/commit/94df1846d2bc7affe077d42e10addca03a09d42b))

## 0.3.0 (2025-08-10)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/Fluidize-Inc/fluidize-python-sdk/compare/v0.2.0...v0.3.0)

### Features

* **api:** api update ([0c74231](https://github.com/Fluidize-Inc/fluidize-python-sdk/commit/0c742316a30eff0b3878f5fcffe478ceeaa1843e))
* **api:** removed requirement for firebase tokens ([cdf4c18](https://github.com/Fluidize-Inc/fluidize-python-sdk/commit/cdf4c1865532c639c36e56caf40bb63c37b2d11d))


### Chores

* **internal:** update comment in script ([6d0708a](https://github.com/Fluidize-Inc/fluidize-python-sdk/commit/6d0708a5c441475d7dce06c50348b72776a48911))
* update @stainless-api/prism-cli to v5.15.0 ([36163e5](https://github.com/Fluidize-Inc/fluidize-python-sdk/commit/36163e52f3198687cfe32d6dd0734932cf6747e6))

## 0.2.0 (2025-08-08)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/Fluidize-Inc/fluidize-python-sdk/compare/v0.1.0...v0.2.0)

### Features

* **api:** auth fixed ([a96f40d](https://github.com/Fluidize-Inc/fluidize-python-sdk/commit/a96f40d874e0f7c679c4f11462860cadfe537518))
* **api:** manual updates ([ece3ea7](https://github.com/Fluidize-Inc/fluidize-python-sdk/commit/ece3ea7c6544c3ea63dd7119b291bc59d8865c5a))

## 0.1.0 (2025-08-08)

Full Changelog: [v0.0.2...v0.1.0](https://github.com/Fluidize-Inc/fluidize-python-sdk/compare/v0.0.2...v0.1.0)

### Features

* **api:** API Endpoint Updated ([aa7652b](https://github.com/Fluidize-Inc/fluidize-python-sdk/commit/aa7652b9348b2fd642889a1d31b5d86962018900))

## 0.0.2 (2025-08-08)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/Fluidize-Inc/fluidize-python-sdk/compare/v0.0.1...v0.0.2)

### Chores

* update SDK settings ([f5aaa87](https://github.com/Fluidize-Inc/fluidize-python-sdk/commit/f5aaa8785665246e6da58be411c0f802c2f0f6bb))
* update SDK settings ([8d6d19a](https://github.com/Fluidize-Inc/fluidize-python-sdk/commit/8d6d19ab54fb9d59a796d33f5938ec41c8e811e1))
